#!/usr/bin/env ruby
require_relative 'APICommunicatorRuby'

# This Code uses the MediaPortalAPICommunicater class to
# send test GET and POST calls to the Media Portal API.
# Test calls are found at the bottom of the file.

#Declare API Key ID and Secret here
@keyId = nil
@keySecret = nil

# A Test GET call to the Media Portal API
# Some fields have been pre-filled out, as appropriate.
# Any Fields directly pertaining to API Key Credentials
# have been left blank. An example API call is included
# below.
def testAPICallGet()
  accept = "application/json"
  dateStr = Time.now.utc.strftime "%a, %d %b %Y %H:%M:%S GMT"  #Need the current time in GMT
  url = "https://ws.level3.com/key/v1.0"

  puts "--------------------Testing API GET Call Start--------------------"
  apiCommunicator = MediaPortalAPICommunicator.new @keyId, @keySecret
  responseStr = apiCommunicator.sendTestAPICallGET url, accept, dateStr
  puts "\n*****Response*****\n#{responseStr}\n*******End********"
  puts "---------------------Testing API GET Call End---------------------\n\n"
end

# A Test POST call to the Media Portal API
# Some fields have been pre-filled out, as appropriate.
# Any Fields directly pertaining to API Key Credentials
# have been left blank. An example API call is included
# with areas marked for you to input your own data.
def testAPICallPost()
  accept = "application/json"
  contentType = "application/json"
  dateStr = Time.now.utc.strftime "%a, %d %b %Y %H:%M:%S GMT"  #Need the current time in GMT
  postBody = '{"paths":["/fake/path/for/testing/nonexistantFile.jpg"]}';

  #Example URL, with info filled out:
  #   https://ws.level3.com/invalidations/v1.0/0000/BB000/apiCall.property.test.net?force=false&ignoreCase=false&notification=test@email.com
  #   ("?" and parameters are optional)
  url = "https://ws.level3.com/invalidations/v1.0/{agid}[/{scid}][/{property}]?[force=true|false][&ignoreCase=true|false][&notification={email}]"

  puts "--------------------Testing API POST Call Start--------------------"
  apiCommunicator = MediaPortalAPICommunicator.new @keyId, @keySecret
  responseStr = apiCommunicator.sendTestAPICallPOST url, accept, contentType, dateStr, postBody
  puts "\n*****Response*****\n#{responseStr}\n*******End********"
  puts "---------------------Testing API POST Call End---------------------\n\n"
end

if __FILE__ == $0
  if(@keyId != nil && @keySecret != nil)
    #Uncomment these tests after declaring all required variables.
    #testAPICallGet
    #testAPICallPost
  else
    puts "**ERROR** Must set the keyId and keySecret variables before running tests."
  end
end
